# -*- R -*-
# $RCSfile: Rdbi-connectionMethods.R,v $
# $Date: 2001/03/26 20:40:38 $
# $Revision: 1.1.1.1 $
# Copyright 2001, Timothy H. Keitt
# Licence: GPL

#
# Methods to implement Rdbi interface
#

PgSQL <- function() {

  out <- list(description = "PostgreSQL object")

  class(out) <- c("PgSQL", "Rdbi")

  return(out)

}

dbConnect.PgSQL <- function(dbObj, ...) {

  conninfo <- list.to.key.pair.string(list(...))
  # list.to.key.pair.string defined in util.R in Rdbi

  conn <- .Call("PgSQLconnect", conninfo)

  class(conn) <- c("PgSQL.conn", "Rdbi.conn")

  attr(conn, "load.library") <- call("library", "Rdbi.PgSQL")
  # allows automatic loading of methods

  attr(conn, "connect.call") <- match.call()
  # allows connection to be recreated later

  if (dbConnectionOK(conn))
    dbSendQuery(conn, "SET DATESTYLE TO 'Postgres, US'");
  # Necessary to make dates() and times() work

  return(conn)

}

dbDisconnect.PgSQL.conn <- function(conn) {

  .Call("PgSQLcloseConnection", conn)

}

dbReconnect.PgSQL.conn <- function(conn) {

  dbDisconnect(conn)
  # this should be a no-op for dead connections
  
  eval(attr(conn, "connect.call"))
  # reconnect and return conn
  
}

dbConnectionOK.PgSQL.conn <- function(conn)
  .Call("PgSQLconnectionOK", conn)

print.PgSQL.conn <- function(conn) {

  if (!dbConnectionOK(conn)) stop("Not connected")

  conninfo <- .Call("PgSQLconnectionInfo", conn)

  for (i in names(conninfo))
    if (conninfo[[i]] != "")
      cat(i, "=", conninfo[[i]], "\n")
  
}

summary.PgSQL.conn <- function(conn) {

  query <- paste("SELECT",
                 "relname as table_name,",
                 "relpages as pages,",
                 "reltuples as tuples",
                 "FROM pg_class",
                 "WHERE relname NOT ~ '^pg_'")
  
  dbSendQuery(conn, query)

}



