# -*- R -*-
# $RCSfile: connectionMethods.R,v $
# $Date: 2001/03/26 20:40:38 $
# $Revision: 1.1.1.1 $
# Copyright 2001, Timothy H. Keitt
# Licence: GPL
#

#
# Generic method to be subclassed for each implementation
#

dbConnect <- function(dbObj, ...) UseMethod("dbConnect")
#
# dbObj should be generated by an implementation defined function,
# e.g., RPgSQL(), which returns a object with an approprite class
# name, e.g., "PostgreSQL" or "MySQL".  The implementation then
# provides a method that actually opens the connection.  
#

dbDisconnect <- function(conn) UseMethod("dbDisconnect")
#
# Close connection and free resources
#

dbReconnect <- function(conn) UseMethod("dbReconnect")
#
# The conn object should store the options passed to dbConnect so that
# it can reestablish the connection.
#

dbConnectionOK <- function(conn) UseMethod("dbConnectionOK")
#
# Returns TRUE if the connection object is valid and the connection
# can be used to communicate with the database backend.
#





#
# Default methods
#

dbConnect.default <- function(dbObj, ...) {

  stop("Invalid database class")
  
}

dbDisconnect.default <- function(conn) {

  stop("Invalid connection object")

}

dbReconnect.default <- function(conn) {


  stop("Invalid connection object")

}

dbConnectionOK.default <- function(conn) {

  return(FALSE)
  
}
    



